@@ -15,7 +15,6 @@
 #include <KDBusService>
 #include <KLocalizedString>
 #include <KPluginMetaData>
-#include <KQuickAddons/QtQuickSettings>
 #include <KWindowSystem>
 #include <iostream>
 #include <kworkspace.h>
@@ -43,8 +42,9 @@ int main(int argc, char *argv[])
     KWorkSpace::detectPlatform(argc, argv);
 
     QApplication application(argc, argv);
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     application.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
-
+#endif
     // The ki18n application domain must be set before we make any i18n() calls.
     KLocalizedString::setApplicationDomain(binaryName.toUtf8().constData());
 
@@ -129,7 +129,7 @@ int main(int argc, char *argv[])
         return -1;
     }
 
-    const QStringList args = parser.value(QStringLiteral("args")).split(QRegExp(QStringLiteral(" +")), Qt::SkipEmptyParts);
+    const QStringList args = parser.value(QStringLiteral("args")).split(QRegularExpression(QStringLiteral(" +")), Qt::SkipEmptyParts);
     QString startupModule;
 
     if (parser.positionalArguments().count() == 1) {
@@ -143,7 +143,6 @@ int main(int argc, char *argv[])
 
     KDBusService service(KDBusService::Unique);
 
-    KQuickAddons::QtQuickSettings::init();
     KCrash::initialize();
 
     SettingsBase *mainWindow = new SettingsBase(mode);
@@ -159,7 +158,7 @@ int main(int argc, char *argv[])
 
         parser.parse(arguments);
 
-        const QStringList args = parser.value(QStringLiteral("args")).split(QRegExp(QStringLiteral(" +")), Qt::SkipEmptyParts);
+        const QStringList args = parser.value(QStringLiteral("args")).split(QRegularExpression(QStringLiteral(" +")), Qt::SkipEmptyParts);
         QString startupModule;
 
         if (parser.positionalArguments().count() == 1) {
