@@ -116,7 +116,11 @@ void IconMode::initEvent()
 
 void IconMode::searchChanged(const QString &text)
 {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     d->proxyModel->setFilterRegExp(text);
+#else
+    d->proxyModel->setFilterRegularExpression(text);
+#endif
     if (d->categoryView) {
         QAbstractItemModel *model = d->categoryView->model();
         const int column = d->categoryView->modelColumn();
@@ -135,7 +139,7 @@ void IconMode::changeModule(const QModelIndex &activeModule)
 {
     // Already loaded?
     MenuItem *item = activeModule.data(Qt::UserRole).value<MenuItem *>();
-    if (d->moduleView->activeModuleName() == &item->name())
+    if (d->moduleView->activeModuleName() == item->name())
         return;
 
     changeModuleWithArgs(activeModule, QStringList());
